@@ -7,10 +7,10 @@ solve.pentadiag <- function(a, b,...){
 		stop("'a' and 'b' should be of same length!")
 	n <- length(b)
 	aaa <- diag(a)
-	bb <- c(diag(a[-n,-1]), 0)
-	c <- c(diag(a[-c(n, n-1), -c(1,2)]), 0, 0)
-	d <- c(0, diag(a[-1,-n]))
-	e <- c(0, 0, diag(a[-c(1,2), -c(n,n-1)]))
+	bb <- c(a[cbind(1:(n-1), 2:n)], 0)
+	c <- c(a[cbind(1:(n-2), 3:n)], 0, 0)
+	d <- c(0, a[cbind(2:n, 1:(n-1))])
+	e <- c(0, 0, a[cbind(3:n, 1:(n-2))])
 	u <- v <- w <- p <- q <- r <- s <- t <- aa <- dd <- rep_len(0,n+2)
 	z <- rep_len(0,n)
 	BB <- .C("penta", as.integer(n), as.double(aaa), as.double(bb), as.double(c), as.double(d),
